import React, { useState, useRef, useCallback } from 'react';
import classnames from 'classnames';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import style from './style.css';
import propTypes from './types';
const COMPONENT_ID = 'input-select';
const InputSelect = ({
  options = [],
  value,
  onChange,
  placeholder,
  className,
  'aria-label': ariaLabel,
  iconClosed = 'chevron-down',
  selectedIcon = 'circle-check',
  'button-data-testid': buttonDataTestId = 'select-input'
}) => {
  const [open, setOpen] = useState(false);
  const wrapperRef = useRef(null);
  const componentId = `${COMPONENT_ID}-${placeholder?.toLowerCase().replace(/\s+/g, '-') || 'default'}`;
  const handleToggle = useCallback(() => {
    setOpen(o => !o);
  }, []);
  const handleOnOptionClick = useCallback(optionValue => {
    onChange(optionValue);
    setOpen(false);
  }, [onChange]);
  React.useEffect(() => {
    if (!open) return;
    const handleClickOutside = event => {
      if (!wrapperRef.current?.contains(event.target)) {
        setOpen(false);
      }
    };
    document.addEventListener('mousedown', handleClickOutside);
    return () => document.removeEventListener('mousedown', handleClickOutside);
  }, [open]);
  const selectedOption = options.find(opt => opt.value === value);
  const renderOption = option => {
    function handleClick() {
      handleOnOptionClick(option.value);
    }
    const isSelected = option.value === value;
    return /*#__PURE__*/React.createElement("li", {
      key: option.value,
      className: classnames(style.option, isSelected && style.selected),
      role: "option",
      "aria-selected": isSelected,
      onClick: handleClick,
      "data-testid": `option-${option.value}`,
      "data-name": option['data-name']
    }, /*#__PURE__*/React.createElement("span", {
      className: style.optionIcon
    }, option.icon), /*#__PURE__*/React.createElement("span", {
      className: style.optionLabel
    }, option.label), isSelected ? /*#__PURE__*/React.createElement("span", {
      className: style.checkIcon
    }, /*#__PURE__*/React.createElement(FontAwesomeIcon, {
      icon: selectedIcon
    })) : null);
  };
  return /*#__PURE__*/React.createElement("div", {
    className: classnames(style.outerWrapper, {
      [style.open]: open
    })
  }, /*#__PURE__*/React.createElement("div", {
    ref: wrapperRef,
    className: classnames(style.wrapper, className),
    "aria-label": ariaLabel
  }, /*#__PURE__*/React.createElement("button", {
    type: "button",
    className: style.display,
    onClick: handleToggle,
    "aria-haspopup": "listbox",
    "aria-expanded": open,
    "aria-controls": open ? `${componentId}-listbox` : undefined,
    id: componentId,
    "data-testid": buttonDataTestId
  }, /*#__PURE__*/React.createElement("div", {
    className: style.content
  }, /*#__PURE__*/React.createElement("span", {
    className: style.label
  }, placeholder), selectedOption ? /*#__PURE__*/React.createElement("span", {
    className: style.value
  }, selectedOption.label) : null), /*#__PURE__*/React.createElement("span", {
    className: classnames(style.iconWrapper, {
      [style.open]: open
    })
  }, /*#__PURE__*/React.createElement(FontAwesomeIcon, {
    className: classnames(style.icon, {
      [style.rotated]: open
    }),
    icon: iconClosed
  }))), open ? /*#__PURE__*/React.createElement("ul", {
    id: `${componentId}-listbox`,
    className: style.menu,
    role: "listbox"
  }, options.map(renderOption)) : null));
};
InputSelect.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
export default InputSelect;
//# sourceMappingURL=index.js.map