"use strict";

exports.__esModule = true;
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _classnames = _interopRequireDefault(require("classnames"));
var _reactFontawesome = require("@fortawesome/react-fontawesome");
var _style = _interopRequireDefault(require("./style.css"));
var _types = _interopRequireDefault(require("./types"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const COMPONENT_ID = 'input-select';
const InputSelect = ({
  options = [],
  value,
  onChange,
  placeholder,
  className,
  'aria-label': ariaLabel,
  iconClosed = 'chevron-down',
  selectedIcon = 'circle-check',
  'button-data-testid': buttonDataTestId = 'select-input'
}) => {
  const [open, setOpen] = (0, _react.useState)(false);
  const wrapperRef = (0, _react.useRef)(null);
  const componentId = `${COMPONENT_ID}-${placeholder?.toLowerCase().replace(/\s+/g, '-') || 'default'}`;
  const handleToggle = (0, _react.useCallback)(() => {
    setOpen(o => !o);
  }, []);
  const handleOnOptionClick = (0, _react.useCallback)(optionValue => {
    onChange(optionValue);
    setOpen(false);
  }, [onChange]);
  _react.default.useEffect(() => {
    if (!open) return;
    const handleClickOutside = event => {
      if (!wrapperRef.current?.contains(event.target)) {
        setOpen(false);
      }
    };
    document.addEventListener('mousedown', handleClickOutside);
    return () => document.removeEventListener('mousedown', handleClickOutside);
  }, [open]);
  const selectedOption = options.find(opt => opt.value === value);
  const renderOption = option => {
    function handleClick() {
      handleOnOptionClick(option.value);
    }
    const isSelected = option.value === value;
    return /*#__PURE__*/_react.default.createElement("li", {
      key: option.value,
      className: (0, _classnames.default)(_style.default.option, isSelected && _style.default.selected),
      role: "option",
      "aria-selected": isSelected,
      onClick: handleClick,
      "data-testid": `option-${option.value}`,
      "data-name": option['data-name']
    }, /*#__PURE__*/_react.default.createElement("span", {
      className: _style.default.optionIcon
    }, option.icon), /*#__PURE__*/_react.default.createElement("span", {
      className: _style.default.optionLabel
    }, option.label), isSelected ? /*#__PURE__*/_react.default.createElement("span", {
      className: _style.default.checkIcon
    }, /*#__PURE__*/_react.default.createElement(_reactFontawesome.FontAwesomeIcon, {
      icon: selectedIcon
    })) : null);
  };
  return /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _classnames.default)(_style.default.outerWrapper, {
      [_style.default.open]: open
    })
  }, /*#__PURE__*/_react.default.createElement("div", {
    ref: wrapperRef,
    className: (0, _classnames.default)(_style.default.wrapper, className),
    "aria-label": ariaLabel
  }, /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    className: _style.default.display,
    onClick: handleToggle,
    "aria-haspopup": "listbox",
    "aria-expanded": open,
    "aria-controls": open ? `${componentId}-listbox` : undefined,
    id: componentId,
    "data-testid": buttonDataTestId
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _style.default.content
  }, /*#__PURE__*/_react.default.createElement("span", {
    className: _style.default.label
  }, placeholder), selectedOption ? /*#__PURE__*/_react.default.createElement("span", {
    className: _style.default.value
  }, selectedOption.label) : null), /*#__PURE__*/_react.default.createElement("span", {
    className: (0, _classnames.default)(_style.default.iconWrapper, {
      [_style.default.open]: open
    })
  }, /*#__PURE__*/_react.default.createElement(_reactFontawesome.FontAwesomeIcon, {
    className: (0, _classnames.default)(_style.default.icon, {
      [_style.default.rotated]: open
    }),
    icon: iconClosed
  }))), open ? /*#__PURE__*/_react.default.createElement("ul", {
    id: `${componentId}-listbox`,
    className: _style.default.menu,
    role: "listbox"
  }, options.map(renderOption)) : null));
};
InputSelect.propTypes = process.env.NODE_ENV !== "production" ? _types.default : {};
var _default = exports.default = InputSelect;
//# sourceMappingURL=index.js.map