export default Vimeo;
declare class Vimeo extends React.Component<any, any, any> {
    static propTypes: {
        /**
         * A Vimeo ID or URL.
         */
        id: PropTypes.Requireable<NonNullable<string | number | null | undefined>>;
        /**
         * CSS className for the player element.
         */
        className: PropTypes.Requireable<string>;
        /**
         * Width of the player element.
         */
        width: PropTypes.Requireable<NonNullable<string | number | null | undefined>>;
        /**
         * Height of the player element.
         */
        height: PropTypes.Requireable<NonNullable<string | number | null | undefined>>;
        /**
         * Pause the video.
         */
        paused: PropTypes.Requireable<boolean>;
        /**
         * Pause this video automatically when another one plays.
         */
        autopause: PropTypes.Requireable<boolean>;
        /**
         * Automatically start playback of the video. Note that this won’t work on
         * some devices.
         */
        autoplay: PropTypes.Requireable<boolean>;
        /**
         * Show the byline on the video.
         */
        showByline: PropTypes.Requireable<boolean>;
        /**
         * Specify the color of the video controls. Colors may be overridden by the
         * embed settings of the video.
         */
        color: PropTypes.Requireable<string>;
        /**
         * Play the video again when it reaches the end.
         */
        loop: PropTypes.Requireable<boolean>;
        /**
         * Show the portrait on the video.
         */
        showPortrait: PropTypes.Requireable<boolean>;
        /**
         * Show the title on the video.
         */
        showTitle: PropTypes.Requireable<boolean>;
        /**
         * Sent when the Vimeo player API has loaded.
         */
        onReady: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Sent when the player triggers an error.
         */
        onError: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Triggered when the video plays.
         */
        onPlay: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Triggered when the video pauses.
         */
        onPause: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Triggered any time the video playback reaches the end.
         * Note: when `loop` is turned on, the ended event will not fire.
         */
        onEnd: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Triggered as the `currentTime` of the video updates. It generally fires
         * every 250ms, but it may vary depending on the browser.
         */
        onTimeUpdate: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Triggered as the video is loaded. Reports back the amount of the video
         * that has been buffered.
         */
        onProgress: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Triggered when the player seeks to a specific time. An `onTimeUpdate`
         * event will also be fired at the same time.
         */
        onSeeked: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Triggered when the active text track (captions/subtitles) changes. The
         * values will be `null` if text tracks are turned off.
         */
        onTextTrackChange: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Triggered when the active cue for the current text track changes. It also
         * fires when the active text track changes. There may be multiple cues
         * active.
         */
        onCueChange: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Triggered when the current time hits a registered cue point.
         */
        onCuePoint: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Triggered when the volume in the player changes. Some devices do not
         * support setting the volume of the video independently from the system
         * volume, so this event will never fire on those devices.
         */
        onVolumeChange: PropTypes.Requireable<(...args: any[]) => any>;
        /**
         * Triggered when a new video is loaded in the player.
         */
        onLoaded: PropTypes.Requireable<(...args: any[]) => any>;
    };
    static contextTypes: {
        Vimeo: PropTypes.Requireable<object>;
    };
    static defaultProps: {
        autopause: boolean;
        autoplay: boolean;
        loop: boolean;
        showByline: boolean;
        showPortrait: boolean;
        showTitle: boolean;
    };
    constructor(props: any, context: any);
    refContainer(container: any): void;
    state: {
        isLoading: boolean;
    };
    componentDidMount(): void;
    componentDidUpdate(prevProps: any): void;
    getInitialOptions(): {
        id: any;
        width: any;
        height: any;
        autopause: any;
        autoplay: any;
        byline: any;
        color: any;
        loop: any;
        portrait: any;
        title: any;
    };
    updateProps(propNames: any): void;
    createPlayer(): null | undefined;
    player: any;
    container: any;
    render(): JSX.Element;
}
import React from "react";
import PropTypes from "prop-types";
//# sourceMappingURL=vimeo.d.ts.map